## Meta Sepia
#
# sidebar.rb
# initializes the sidebar including the sparse navigation tree and the search
# facilities
#
# author::    Peter Rullmann (mailto:peter@p4n.net)
# copyright:: Copyright (c) 2006-2008 Peter Rullmann
#
# You can Freely distribute this program under the GNU General Public
# License. See the file "COPYING" for the exact licensing terms.

class Sidebar

  ICON_SIZE = 18


  def initialize
    @foldertree = $glade["foldertree"]
    @treestore = Gtk::TreeStore.new(String, Gdk::Pixbuf, String)
    @foldertree.model= @treestore
    @foldertree.selection.mode= Gtk::SELECTION_SINGLE

    col = Gtk::TreeViewColumn.new("")
    col.pack_start(crp = Gtk::CellRendererPixbuf.new, false)
    col.set_attributes(crp, :pixbuf => 1)
    col.pack_start(crt = Gtk::CellRendererText.new, false)
    col.set_attributes(crt, :text => 0)
    @foldertree.append_column(col)

    @foldertree.signal_connect("size-allocate") do |se, alloc|
      update unless alloc.height == @height
    end

    $location.signal_connect("changed") do
      update
    end

    @foldertree.selection.signal_connect("changed") do |se|
      iter = se.selected
      $location.path= iter[2] unless iter.nil?
    end
    
  end


  def update
    @height = @foldertree.allocation.height
    num_places = (@height + 6) / (ICON_SIZE + 10)
    elems = $location.important_places(num_places -1)
    @treestore.clear

    selected_iter = nil
    parents = [nil]
    icon_theme = Gtk::IconTheme.default
    sorted_keys = elems.keys.sort { |a, b| a.upcase <=> b.upcase }
    sorted_keys.each() do |elem|
      level = elem.count("/")
      name = File.basename(elem)
      icon = elems[elem]
      level, name = [0, "Computer"] if elem == "/"
      node = @treestore.append(parents[ level ])
      parents[level + 1] = node
      node[0] = name
      node[1] = icon_theme.load_icon(icon, ICON_SIZE,
                                     Gtk::IconTheme::LOOKUP_FORCE_SVG)
      node[2] = elem
      selected_iter = node if elem == $location.loc_obj.path
    end

    node = @treestore.append parents[ 0 ]
    node[0] = "Network"
    node[1] = icon_theme.load_icon("network-workgroup", ICON_SIZE,
                                   Gtk::IconTheme::LOOKUP_FORCE_SVG)
    node[2] = "/"
    @foldertree.expand_all
    @foldertree.selection.select_iter(selected_iter)
  end

end


$sidebar = Sidebar.new

